@@ -1,5 +1,5 @@
 ## ---- include=FALSE------------------------------------------------------
-library(icd)
+library("icd")
 
 ## ----setup---------------------------------------------------------------
 Elix_comor <- names(icd9_map_ahrq)
