@@ -156,16 +156,21 @@ test_that("#97 is fixed", {
 
 test_that("icd10 short to decimal for multiple codes", {
   # pick up specific bug where a warning was given for muliple codes
-  expect_error(res <- short_to_decimal(c("O9A119", "O9A53", "S0000XA", "T3299", "P150", "P159",
-                                               "Z9989", "Z950", "C7A098", "C7A8")), regexp = NA)
+  expect_error(
+    res <- short_to_decimal(
+      c("O9A119", "O9A53", "S0000XA", "T3299", "P150", "P159",
+        "Z9989", "Z950", "C7A098", "C7A8")), regexp = NA)
 
-  expect_equal(as.vector(res), c("O9A.119", "O9A.53", "S00.00XA", "T32.99", "P15.0", "P15.9",
-                                 "Z99.89", "Z95.0", "C7A.098", "C7A.8"))
+  expect_equal(as.vector(res),
+               c("O9A.119", "O9A.53", "S00.00XA", "T32.99", "P15.0", "P15.9",
+                 "Z99.89", "Z95.0", "C7A.098", "C7A.8"))
   expect_true(is.icd_decimal_diag(res))
 
   # is the icd10cm class preserved?
-  expect_error(res <- short_to_decimal(icd10cm(c("O9A119", "O9A53", "S0000XA", "T3299", "P150", "P159",
-                                                       "Z9989", "Z950", "C7A098", "C7A8"))), regexp = NA)
+  expect_error(
+    res <- short_to_decimal(icd10cm(
+      c("O9A119", "O9A53", "S0000XA", "T3299", "P150", "P159",
+        "Z9989", "Z950", "C7A098", "C7A8"))), regexp = NA)
 
   expect_true(is.icd_decimal_diag(res))
   expect_true(is.icd10cm(res))
@@ -173,10 +178,14 @@ test_that("icd10 short to decimal for multiple codes", {
 })
 
 test_that("icd10 short to decimal and back", {
-  expect_identical(short_to_decimal(icd_decimal_to_short("A00.0")), as.icd10("A00.0") %>% as.icd_decimal_diag)
-  expect_identical(icd_decimal_to_short(short_to_decimal("A000")), as.icd10("A000") %>% as.icd_short_diag)
-  expect_identical(short_to_decimal.icd10(icd_decimal_to_short.icd10("A00.0")), as.icd10("A00.0") %>% as.icd_decimal_diag)
-  expect_identical(icd_decimal_to_short.icd10(short_to_decimal.icd10("A000")), as.icd10("A000") %>% as.icd_short_diag)
+  expect_identical(short_to_decimal(icd_decimal_to_short("A00.0")),
+                   as.icd10("A00.0") %>% as.icd_decimal_diag)
+  expect_identical(icd_decimal_to_short(short_to_decimal("A000")),
+                   as.icd10("A000") %>% as.icd_short_diag)
+  expect_identical(short_to_decimal.icd10(icd_decimal_to_short.icd10("A00.0")),
+                   as.icd10("A00.0") %>% as.icd_decimal_diag)
+  expect_identical(icd_decimal_to_short.icd10(short_to_decimal.icd10("A000")),
+                   as.icd10("A000") %>% as.icd_short_diag)
 })
 
 test_that("icd9 short to major part, E codes", {
@@ -191,63 +200,56 @@ test_that("icd9 short to major part, E codes", {
 
 })
 
-test_that("running short to decimal conversion before and after expansion
-          of a ICD-9 base codes gives the same result", {
+test_that("short to decimal before and after ICD-9 expansion is same", {
+  icd9List <- icd9_map_ahrq #todo SUBSET OR EXTRA MAPPINGS?
+  for (i in names(icd9List)) {
+    expect_equal_no_icd(
+      icd_decimal_to_short.icd9(short_to_decimal.icd9(icd9List[[i]])),
+      icd9_add_leading_zeroes(icd9List[[i]], short_code = TRUE),
+      info = paste("step 1, iteration:", i)
+    )
+    expect_equal_no_icd(
+      icd_decimal_to_short(short_to_decimal(icd9List[[i]])),
+      icd9_add_leading_zeroes(icd9List[[i]], short_code = TRUE),
+      info = paste("step 2, iteration:", i)
+    )
+  }
 
-            icd9List <- icd9_map_ahrq #todo SUBSET OR EXTRA MAPPINGS?
-            for (i in names(icd9List)) {
-              expect_equal_no_icd(
-                icd_decimal_to_short.icd9(short_to_decimal.icd9(icd9List[[i]])),
-                icd9_add_leading_zeroes(icd9List[[i]], short_code = TRUE),
-                info = paste("step 1, iteration:", i)
-              )
+  n <- 50
+  set.seed(1441)
+  rd9 <- paste(
+    sprintf("%d", round(stats::runif(min = 1, max = 199, n = n))),
+    sample(expand_minor.icd9("", is_e = FALSE), replace = TRUE, size = n)[-1],
+    sep = "."
+  )
+  rd9pad <- icd9_add_leading_zeroes(rd9)
+  expect_equal_no_icd(
+    short_to_decimal.icd9(icd_decimal_to_short.icd9(rd9)),
+    rd9pad
+  )
+  # same with function to dispatch appropriately
+  expect_equal_no_icd(
+    short_to_decimal(icd_decimal_to_short(rd9)),
+    rd9pad
+  )
 
-              expect_equal_no_icd(
-                icd_decimal_to_short(short_to_decimal(icd9List[[i]])),
-                icd9_add_leading_zeroes(icd9List[[i]], short_code = TRUE),
-                info = paste("step 2, iteration:", i)
-              )
-            }
-
-            n <- 50
-            set.seed(1441)
-            rd9 <- paste(
-              sprintf("%d", round(stats::runif(min = 1, max = 199, n = n))),
-              sample(expand_minor.icd9("", is_e = FALSE), replace = TRUE, size = n)[-1],
-              sep = "."
-            )
-            rd9pad <- icd9_add_leading_zeroes(rd9)
-            expect_equal_no_icd(
-              short_to_decimal.icd9(icd_decimal_to_short.icd9(rd9)),
-              rd9pad
-            )
-
-            # same with function to dispatch appropriately
-            expect_equal_no_icd(
-              short_to_decimal(icd_decimal_to_short(rd9)),
-              rd9pad
-            )
-
-            # test without decimal, too... starting with non-zero-spaced shorts
-            set.seed(1441)
-            rd2 <- as.character(round(stats::runif(min = 1, max = 999, n = n)))
-            set.seed(1441)
-            rd2pad <- sprintf("%03d", round(stats::runif(min = 1, max = 999, n = n)))
-            expect_equal_no_icd(short_to_decimal.icd9(icd_decimal_to_short.icd9(rd2)), rd2pad)
-            expect_equal_no_icd(icd_decimal_to_short.icd9(short_to_decimal.icd9(rd2)), rd2pad)
-
-            expect_equal_no_icd(short_to_decimal.icd9(icd_decimal_to_short.icd9(rd2pad)), rd2pad)
-
-            expect_equal_no_icd(icd_decimal_to_short.icd9("123."), "123")
-          })
+  # test without decimal, too... starting with non-zero-spaced shorts
+  set.seed(1441)
+  rd2 <- as.character(round(stats::runif(min = 1, max = 999, n = n)))
+  set.seed(1441)
+  rd2pad <- sprintf("%03d", round(stats::runif(min = 1, max = 999, n = n)))
+  expect_equal_no_icd(short_to_decimal.icd9(icd_decimal_to_short.icd9(rd2)), rd2pad)
+  expect_equal_no_icd(icd_decimal_to_short.icd9(short_to_decimal.icd9(rd2)), rd2pad)
+  expect_equal_no_icd(short_to_decimal.icd9(icd_decimal_to_short.icd9(rd2pad)), rd2pad)
+  expect_equal_no_icd(icd_decimal_to_short.icd9("123."), "123")
+})
 
 
-test_that("minimal test case for showing why padding zeroes before decimal conv without class matters", {
+test_that("show why padding zeroes before decimal conv without class matters", {
   expect_equal_no_icd(short_to_decimal(icd_decimal_to_short("12.3")), "012.3")
 })
 
 test_that("short to decimal conversions also convert class", {
-
   expect_true(
     is.icd_short_diag(
       icd_decimal_to_short(
@@ -255,7 +257,6 @@ test_that("short to decimal conversions also convert class", {
       )
     )
   )
-
   expect_true(
     is.icd_decimal_diag(
       short_to_decimal(
@@ -263,7 +264,6 @@ test_that("short to decimal conversions also convert class", {
       )
     )
   )
-
   expect_true(
     is.icd_short_diag(
       icd_decimal_to_short.icd9(
@@ -271,7 +271,6 @@ test_that("short to decimal conversions also convert class", {
       )
     )
   )
-
   expect_true(
     is.icd_decimal_diag(
       short_to_decimal.icd9(
@@ -279,7 +278,6 @@ test_that("short to decimal conversions also convert class", {
       )
     )
   )
-
 })
 
 test_that("parts to decimal", {
@@ -294,7 +292,6 @@ test_that("parts to decimal", {
 test_that("parts to short invalid inputs", {
   dfempty <- list(mjr = character(), mnr = character())
   dfe2 <- list(mjr = "", mnr = "")
-
   expect_equal(icd9PartsToShort(dfempty), character())
   expect_equal(icd9PartsToShort(dfe2), NA_character_)
   expect_equal(icd9PartsToShort(list(mjr = NA, mnr = "trout")), NA_character_)
@@ -305,7 +302,6 @@ test_that("parts to short invalid inputs", {
 })
 
 test_that("parts to valid short with empty or NA minor", {
-
   for (mn in c("", NA)) {
     # leading zeroes should default to true for codes <100 without minor part:
     # more consistent, because any code <100 with a minor must be zero padded to
